@@ -309,6 +309,7 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	int *action)
 {
 	gboolean same_fs;
+	gboolean target_is_source_parent;
 	GnomeVFSURI *target_uri;
 	GnomeVFSURI *dropped_uri;
 	GdkDragAction actions;
@@ -379,14 +380,16 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	/* Compare the first dropped uri with the target uri for same fs match. */
 	dropped_uri = gnome_vfs_uri_new (((NautilusDragSelectionItem *)items->data)->uri);
 	same_fs = TRUE;
+	target_is_source_parent = FALSE;
 
 	if (dropped_uri != NULL) {
 		gnome_vfs_check_same_fs_uris (dropped_uri, target_uri, &same_fs);
+		target_is_source_parent = gnome_vfs_uri_is_parent (target_uri, dropped_uri, FALSE);
 		gnome_vfs_uri_unref (dropped_uri);
 	}
 	gnome_vfs_uri_unref (target_uri);
 	
-	if (same_fs) {
+	if (same_fs || target_is_source_parent) {
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
 		} else {
