@@ -25,6 +25,7 @@
 
 #include <libgnome/gnome-macros.h>
 #include <libgnome/gnome-i18n.h>
+#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -55,7 +56,8 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 				   NautilusIconData      *data,
 				   GList                **emblem_icons,
 				   char                 **embedded_text,
-				   gboolean              *embedded_text_needs_loading)
+				   gboolean              *embedded_text_needs_loading,
+				   gboolean              *has_window_open)
 {
 	FMIconView *icon_view;
 	EelStringList *emblems_to_ignore;
@@ -79,9 +81,32 @@ fm_icon_container_get_icon_images (NautilusIconContainer *container,
 		eel_string_list_free (emblems_to_ignore);
 	}
 
+	*has_window_open = nautilus_file_has_open_window (file);
+	
 	return nautilus_icon_factory_get_icon_for_file (file, TRUE);
 }
 
+static char *
+fm_icon_container_get_icon_description (NautilusIconContainer *container,
+				        NautilusIconData      *data)
+{
+	NautilusFile *file;
+	char *mime_type;
+	const char *description;
+
+	file = NAUTILUS_FILE (data);
+	g_assert (NAUTILUS_IS_FILE (file));
+
+	if (NAUTILUS_IS_DESKTOP_ICON_FILE (file)) {
+		return NULL;
+	}
+
+	mime_type = nautilus_file_get_mime_type (file);
+	description = gnome_vfs_mime_get_description (mime_type);
+	g_free (mime_type);
+	return g_strdup (description);
+}
+
 static void
 fm_icon_container_start_monitor_top_left (NautilusIconContainer *container,
 					  NautilusIconData      *data,
@@ -331,29 +356,30 @@ get_sort_category (NautilusFile *file)
 	NautilusDesktopLink *link;
 	SortCategory category;
 
+	category = SORT_OTHER;
+	
 	if (NAUTILUS_IS_DESKTOP_ICON_FILE (file)) {
 		link = nautilus_desktop_icon_file_get_link (NAUTILUS_DESKTOP_ICON_FILE (file));
-		
-		switch (nautilus_desktop_link_get_link_type (link)) {
-		case NAUTILUS_DESKTOP_LINK_COMPUTER:
-			category = SORT_COMPUTER_LINK;
-			break;
-		case NAUTILUS_DESKTOP_LINK_HOME:
-			category = SORT_HOME_LINK;
-			break;
-		case NAUTILUS_DESKTOP_LINK_VOLUME:
-			category = SORT_MOUNT_LINK;
-			break;
-		case NAUTILUS_DESKTOP_LINK_TRASH:
-			category = SORT_TRASH_LINK;
-			break;
-		default:
-			category = SORT_OTHER;
-			break;
+		if (link != NULL) {
+			switch (nautilus_desktop_link_get_link_type (link)) {
+			case NAUTILUS_DESKTOP_LINK_COMPUTER:
+				category = SORT_COMPUTER_LINK;
+				break;
+			case NAUTILUS_DESKTOP_LINK_HOME:
+				category = SORT_HOME_LINK;
+				break;
+			case NAUTILUS_DESKTOP_LINK_VOLUME:
+				category = SORT_MOUNT_LINK;
+				break;
+			case NAUTILUS_DESKTOP_LINK_TRASH:
+				category = SORT_TRASH_LINK;
+				break;
+			default:
+				category = SORT_OTHER;
+				break;
+			}
+			g_object_unref (link);
 		}
-		g_object_unref (link);
-	} else {
-		category = SORT_OTHER;
 	} 
 	
 	return category;
@@ -446,6 +472,7 @@ fm_icon_container_class_init (FMIconContainerClass *klass)
 
 	ic_class->get_icon_text = fm_icon_container_get_icon_text;
 	ic_class->get_icon_images = fm_icon_container_get_icon_images;
+	ic_class->get_icon_description = fm_icon_container_get_icon_description;
 	ic_class->start_monitor_top_left = fm_icon_container_start_monitor_top_left;
 	ic_class->stop_monitor_top_left = fm_icon_container_stop_monitor_top_left;
 	ic_class->prioritize_thumbnailing = fm_icon_container_prioritize_thumbnailing;
