@@ -69,15 +69,16 @@
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-link.h>
 #include <libnautilus-private/nautilus-metadata.h>
-#include <libnautilus-private/nautilus-sound.h>
 #include <libnautilus-private/nautilus-view-factory.h>
 #include <libnautilus-private/nautilus-clipboard.h>
+#include <libnautilus-private/nautilus-desktop-icon-file.h>
 #include <locale.h>
 #include <signal.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
+#include <esd.h>
 
 #define USE_OLD_AUDIO_PREVIEW 1
 #define READ_CHUNK_SIZE 16384
@@ -85,7 +86,7 @@
 #define POPUP_PATH_ICON_APPEARANCE		"/selection/Icon Appearance Items"
 
 typedef struct {
-	NautilusFileSortType sort_type;
+	const NautilusFileSortType sort_type;
 	const char *metadata_text;
 	const char *action;
 	const char *menu_label;
@@ -168,6 +169,10 @@ static gboolean default_sort_in_reverse_order = FALSE;
 static int preview_sound_auto_value;
 static gboolean gnome_esd_enabled_auto_value;
 
+#if USE_OLD_AUDIO_PREVIEW
+static pid_t audio_preview_pid = 0;
+#endif
+
 static void                 fm_icon_view_set_directory_sort_by        (FMIconView           *icon_view,
 								       NautilusFile         *file,
 								       const char           *sort_by);
@@ -531,7 +536,8 @@ fm_icon_view_add_file (FMDirectoryView *view, NautilusFile *file)
 	}
 	
 	if (nautilus_icon_container_add (icon_container,
-					 NAUTILUS_ICON_CONTAINER_ICON_DATA (file))) {
+					 NAUTILUS_ICON_CONTAINER_ICON_DATA (file),
+					 NAUTILUS_IS_DESKTOP_ICON_FILE (file))) {
 		nautilus_file_ref (file);
 	}
 }
@@ -1219,7 +1225,7 @@ fm_icon_view_can_zoom_out (FMDirectoryView *view)
 static GtkWidget * 
 fm_icon_view_get_background_widget (FMDirectoryView *view) 
 {
-	g_return_val_if_fail (FM_IS_ICON_VIEW (view), FALSE);
+	g_return_val_if_fail (FM_IS_ICON_VIEW (view), NULL);
 
 	return GTK_WIDGET (get_icon_container (FM_ICON_VIEW (view)));
 }
@@ -1377,17 +1383,19 @@ fm_icon_view_can_rename_file (FMDirectoryView *view, NautilusFile *file)
 }
 
 static void
-fm_icon_view_start_renaming_file (FMDirectoryView *view, NautilusFile *file)
+fm_icon_view_start_renaming_file (FMDirectoryView *view,
+				  NautilusFile *file,
+				  gboolean select_all)
 {
 	/* call parent class to make sure the right icon is selected */
-	FM_DIRECTORY_VIEW_CLASS(fm_icon_view_parent_class)->start_renaming_file (view, file);
+	FM_DIRECTORY_VIEW_CLASS(fm_icon_view_parent_class)->start_renaming_file (view, file, select_all);
 	
 	/* start renaming */
 	nautilus_icon_container_start_renaming_selected_item
-		(get_icon_container (FM_ICON_VIEW (view)));
+		(get_icon_container (FM_ICON_VIEW (view)), select_all);
 }
 
-static GtkActionEntry icon_view_entries[] = {
+static const GtkActionEntry icon_view_entries[] = {
   { "Arrange Items", NULL, N_("Arran_ge Items") }, /* name, stock id, label */
   { "Stretch", NULL,                               /* name, stock id */
     N_("Str_etch Icon"), NULL,                     /* label, accelerator */
@@ -1403,7 +1411,7 @@ static GtkActionEntry icon_view_entries[] = {
     G_CALLBACK (action_clean_up_callback) },
 };
 
-static GtkToggleActionEntry icon_view_toggle_entries[] = {
+static const GtkToggleActionEntry icon_view_toggle_entries[] = {
   { "Tighter Layout", NULL,                               /* name, stock id */
     N_("Compact _Layout"), NULL,                     /* label, accelerator */
     N_("Toggle using a tighter layout scheme"),      /* tooltip */ 
@@ -1421,7 +1429,7 @@ static GtkToggleActionEntry icon_view_toggle_entries[] = {
     0 },
 };
 
-static GtkRadioActionEntry arrange_radio_entries[] = {
+static const GtkRadioActionEntry arrange_radio_entries[] = {
   { "Manual Layout", NULL,
     N_("_Manually"), NULL,
     N_("Leave icons wherever they are dropped"),
@@ -1635,6 +1643,14 @@ fm_icon_view_set_selection (FMDirectoryView *view, GList *selection)
 		(get_icon_container (FM_ICON_VIEW (view)), selection);
 }
 
+static gboolean
+fm_icon_view_using_manual_layout (FMDirectoryView *view)
+{
+	g_return_val_if_fail (FM_IS_ICON_VIEW (view), FALSE);
+
+	return !fm_icon_view_using_auto_layout (FM_ICON_VIEW (view));
+}
+
 static void
 icon_container_activate_callback (NautilusIconContainer *container,
 				  GList *file_list,
@@ -1659,7 +1675,8 @@ icon_container_activate_alternate_callback (NautilusIconContainer *container,
 	fm_directory_view_activate_files (FM_DIRECTORY_VIEW (icon_view), 
 					  file_list, 
 					  NAUTILUS_WINDOW_OPEN_ACCORDING_TO_MODE,
-					  NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND);
+					  NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND |
+					  NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW);
 }
 
 static void
@@ -1782,7 +1799,11 @@ play_file (gpointer callback_data)
 		pclose(sound_process);
 		_exit (0);
 	} else if (mp3_pid > (pid_t) 0) {
-		nautilus_sound_register_sound (mp3_pid);
+		if (audio_preview_pid > 0) {
+			kill (-audio_preview_pid, SIGTERM);
+			waitpid (audio_preview_pid, NULL, 0);
+		}
+		audio_preview_pid = mp3_pid;
 	}
 		
 	g_free (file_uri);
@@ -1829,7 +1850,11 @@ preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 {		
 	/* Stop current audio playback */
 #if USE_OLD_AUDIO_PREVIEW
-	nautilus_sound_kill_sound ();
+	if (audio_preview_pid > 0) {
+		kill (-audio_preview_pid, SIGTERM);
+		waitpid (audio_preview_pid, NULL, 0);
+		audio_preview_pid = 0;
+	}
 #else
 	if (icon_view->details->audio_player_data != NULL) {
 		nautilus_audio_player_stop (icon_view->details->audio_player_data);
@@ -1856,11 +1881,20 @@ preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 static gboolean
 should_preview_sound (NautilusFile *file)
 {
+	char *uri;
+
 	/* Check gnome config sound preference */
 	if (!gnome_esd_enabled_auto_value) {
 		return FALSE;
 	}
 
+	uri = nautilus_file_get_uri (file);
+	if (uri && eel_istr_has_prefix (uri, "burn:")) {
+		g_free (uri);
+		return FALSE;
+	}
+	g_free (uri);
+
 	/* Check user performance preference */	
 	if (preview_sound_auto_value == NAUTILUS_SPEED_TRADEOFF_NEVER) {
 		return FALSE;
@@ -1873,6 +1907,29 @@ should_preview_sound (NautilusFile *file)
 	return nautilus_file_is_local (file);
 }
 
+static inline gboolean
+can_play_sound (void)
+{
+	int open_result;
+
+#if USE_OLD_AUDIO_PREVIEW			
+	/* first see if there's already one in progress; if so, return true */
+	if (audio_preview_pid > 0) {
+		return TRUE;
+	}
+#endif
+
+	/* Now check and see if system has audio out capabilites */
+        open_result = esd_open_sound (NULL);
+        if (open_result == -1) {
+                return FALSE;
+        }
+
+	esd_close (open_result);
+
+	return TRUE;
+}
+
 static int
 icon_container_preview_callback (NautilusIconContainer *container,
 				 NautilusFile *file,
@@ -1894,7 +1951,7 @@ icon_container_preview_callback (NautilusIconContainer *container,
 		     || eel_istr_has_prefix (mime_type, "application/x-ogg"))
 		    && eel_strcasecmp (mime_type, "audio/x-pn-realaudio") != 0
 		    && eel_strcasecmp (mime_type, "audio/x-mpegurl") != 0
-		    && nautilus_sound_can_play_sound ()) {
+		    && can_play_sound ()) {
 			result = 1;
 			preview_audio (icon_view, file, start_flag);
 		}	
@@ -1981,7 +2038,8 @@ fm_icon_view_screen_changed (GtkWidget *widget,
 				fm_icon_view_remove_file (view, file);
 			} else {
 				if (nautilus_icon_container_add (icon_container,
-								 NAUTILUS_ICON_CONTAINER_ICON_DATA (file))) {
+								 NAUTILUS_ICON_CONTAINER_ICON_DATA (file),
+								 NAUTILUS_IS_DESKTOP_ICON_FILE (file))) {
 					nautilus_file_ref (file);
 				}
 			}
@@ -2475,6 +2533,14 @@ icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_ur
 						item_uris, action, x, y);
 }
 
+static void
+icon_view_handle_text (NautilusIconContainer *container, const char *text,
+		       GdkDragAction action, int x, int y, FMIconView *view)
+{
+	fm_directory_view_handle_text_drop (FM_DIRECTORY_VIEW (view),
+					    text, action, x, y);
+}
+
 static char *
 icon_view_get_first_visible_file (NautilusView *view)
 {
@@ -2538,6 +2604,7 @@ fm_icon_view_class_init (FMIconViewClass *klass)
 	fm_directory_view_class->get_background_widget = fm_icon_view_get_background_widget;
 	fm_directory_view_class->get_selected_icon_locations = fm_icon_view_get_selected_icon_locations;
 	fm_directory_view_class->get_selection = fm_icon_view_get_selection;
+	fm_directory_view_class->get_selection_for_file_transfer = fm_icon_view_get_selection;
 	fm_directory_view_class->get_item_count = fm_icon_view_get_item_count;
 	fm_directory_view_class->is_empty = fm_icon_view_is_empty;
 	fm_directory_view_class->remove_file = fm_icon_view_remove_file;
@@ -2558,6 +2625,7 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         fm_directory_view_class->start_renaming_file = fm_icon_view_start_renaming_file;
         fm_directory_view_class->text_attribute_names_changed = fm_icon_view_text_attribute_names_changed;
         fm_directory_view_class->update_menus = fm_icon_view_update_menus;
+	fm_directory_view_class->using_manual_layout = fm_icon_view_using_manual_layout;
 
 	klass->clean_up = fm_icon_view_real_clean_up;
 	klass->supports_auto_layout = real_supports_auto_layout;
@@ -2640,6 +2708,8 @@ fm_icon_view_init (FMIconView *icon_view)
 				 G_CALLBACK (icon_view_handle_url), icon_view, 0);
 	g_signal_connect_object (get_icon_container (icon_view), "handle_uri_list",
 				 G_CALLBACK (icon_view_handle_uri_list), icon_view, 0);
+	g_signal_connect_object (get_icon_container (icon_view), "handle_text",
+				 G_CALLBACK (icon_view_handle_text), icon_view, 0);
 }
 
 static NautilusView *
